@@ -23,17 +23,40 @@ SOFTWARE.
 """
 
 from .http import HTTPClient
-from .cache import Cache
-from .models.nsfw import NotSafeForWork
-from .models.sfw import SafeForWork
+from . import NotSafeForWork
+from . import SafeForWork
 
 __all__ = ["Client"]
 
 
 class Client(HTTPClient):
+    """
+    Main client.
+    
+    Example
+    --------
+    
+    .. code:: python
+    
+        import pykawaii
+        import asyncio
+        
+        kawaii = pykawaii.Client()
+        
+        async def main() -> None:
+            sfw_img_url = await kawaii.sfw.waifu()
+            nsfw_img_url = await kawaii.nsfw.waifu()
+            print(sfw_img_url)
+            print(nsfw_img_url)
+
+        if __name__ == "__main__":
+            asyncio.run(main())
+            
+            
+    """
+    
     def __init__(self) -> None:
-        self.cache = Cache
-        super().__init__(self.cache)
+        super().__init__()
 
     @property
     def nsfw(self) -> NotSafeForWork:
